@@ -1,6 +1,6 @@
 package Lowu;
 {
-  $Lowu::VERSION = '1.005000';
+  $Lowu::VERSION = '1.006000';
 }
 use strictures 1;
 
@@ -38,9 +38,15 @@ Lowu - Shortcut for importing list object goodness
 
 =head1 DESCRIPTION
 
-A short-to-type way to get all of List::Objects::WithUtils, including
+A short-to-type way to get all of L<List::Objects::WithUtils>, including
 autoboxing.
 
+If you like, you can specify params as if calling C<use
+List::Objects::WithUtils>:
+
+  # Get array() and immarray() only:
+  use Lowu 'array', 'immarray';
+
 =head1 AUTHOR
 
 Jon Portnoy <avenj@cobaltirc.org>
